# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.paginatedrpm_rpm_distribution_response_list import PaginatedrpmRpmDistributionResponseList

class TestPaginatedrpmRpmDistributionResponseList(unittest.TestCase):
    """PaginatedrpmRpmDistributionResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedrpmRpmDistributionResponseList:
        """Test PaginatedrpmRpmDistributionResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedrpmRpmDistributionResponseList`
        """
        model = PaginatedrpmRpmDistributionResponseList()
        if include_optional:
            return PaginatedrpmRpmDistributionResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/rpm_distribution_response.rpm.RpmDistributionResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        base_path = '', 
                        base_url = '', 
                        content_guard = '', 
                        no_content_change_since = '', 
                        hidden = True, 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        name = '', 
                        repository = '', 
                        publication = '', 
                        generate_repo_config = True, 
                        checkpoint = True, )
                    ]
            )
        else:
            return PaginatedrpmRpmDistributionResponseList(
                count = 123,
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/rpm_distribution_response.rpm.RpmDistributionResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        base_path = '', 
                        base_url = '', 
                        content_guard = '', 
                        no_content_change_since = '', 
                        hidden = True, 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        name = '', 
                        repository = '', 
                        publication = '', 
                        generate_repo_config = True, 
                        checkpoint = True, )
                    ],
        )
        """

    def testPaginatedrpmRpmDistributionResponseList(self):
        """Test PaginatedrpmRpmDistributionResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.rpm_package_response import RpmPackageResponse

class TestRpmPackageResponse(unittest.TestCase):
    """RpmPackageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RpmPackageResponse:
        """Test RpmPackageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RpmPackageResponse`
        """
        model = RpmPackageResponse()
        if include_optional:
            return RpmPackageResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                md5 = '',
                sha1 = '',
                sha224 = '',
                sha256 = '',
                sha384 = '',
                sha512 = '',
                pulp_labels = {
                    'key' : ''
                    },
                vuln_report = '',
                artifact = '',
                name = '',
                epoch = '',
                version = '',
                release = '',
                arch = '',
                pkg_id = '',
                checksum_type = '',
                summary = '',
                description = '',
                url = '',
                changelogs = None,
                files = None,
                requires = None,
                provides = None,
                conflicts = None,
                obsoletes = None,
                suggests = None,
                enhances = None,
                recommends = None,
                supplements = None,
                location_base = '',
                location_href = '',
                rpm_buildhost = '',
                rpm_group = '',
                rpm_license = '',
                rpm_packager = '',
                rpm_sourcerpm = '',
                rpm_vendor = '',
                rpm_header_start = 56,
                rpm_header_end = 56,
                is_modular = True,
                size_archive = 56,
                size_installed = 56,
                size_package = 56,
                time_build = 56,
                time_file = 56
            )
        else:
            return RpmPackageResponse(
        )
        """

    def testRpmPackageResponse(self):
        """Test RpmPackageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from pulpcore.client.pulp_rpm.models.addon_response import AddonResponse
from pulpcore.client.pulp_rpm.models.checksum_response import ChecksumResponse
from pulpcore.client.pulp_rpm.models.image_response import ImageResponse
from pulpcore.client.pulp_rpm.models.variant_response import VariantResponse
from typing import Optional, Set
from typing_extensions import Self

class RpmDistributionTreeResponse(BaseModel):
    """
    DistributionTree serializer.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    header_version: StrictStr = Field(description="Header Version.")
    release_name: StrictStr = Field(description="Release name.")
    release_short: StrictStr = Field(description="Release short name.")
    release_version: StrictStr = Field(description="Release version.")
    release_is_layered: StrictBool = Field(description="Typically False for an operating system, True otherwise.")
    base_product_name: Optional[StrictStr] = Field(description="Base Product name.")
    base_product_short: Optional[StrictStr] = Field(description="Base Product short name.")
    base_product_version: Optional[StrictStr] = Field(description="Base Product version.")
    arch: StrictStr = Field(description="Tree architecturerch.")
    build_timestamp: Union[StrictFloat, StrictInt] = Field(description="Tree build time timestamp.")
    instimage: Optional[StrictStr] = Field(description="Relative path to Anaconda instimage.")
    mainimage: Optional[StrictStr] = Field(description="Relative path to Anaconda stage2 image.")
    discnum: Optional[StrictInt] = Field(description="Disc number.")
    totaldiscs: Optional[StrictInt] = Field(description="Number of discs in media set.")
    addons: List[AddonResponse]
    checksums: List[ChecksumResponse]
    images: List[ImageResponse]
    variants: List[VariantResponse]
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "header_version", "release_name", "release_short", "release_version", "release_is_layered", "base_product_name", "base_product_short", "base_product_version", "arch", "build_timestamp", "instimage", "mainimage", "discnum", "totaldiscs", "addons", "checksums", "images", "variants"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RpmDistributionTreeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in addons (list)
        _items = []
        if self.addons:
            for _item_addons in self.addons:
                if _item_addons:
                    _items.append(_item_addons.to_dict())
            _dict['addons'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in checksums (list)
        _items = []
        if self.checksums:
            for _item_checksums in self.checksums:
                if _item_checksums:
                    _items.append(_item_checksums.to_dict())
            _dict['checksums'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item_images in self.images:
                if _item_images:
                    _items.append(_item_images.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in variants (list)
        _items = []
        if self.variants:
            for _item_variants in self.variants:
                if _item_variants:
                    _items.append(_item_variants.to_dict())
            _dict['variants'] = _items
        # set to None if base_product_name (nullable) is None
        # and model_fields_set contains the field
        if self.base_product_name is None and "base_product_name" in self.model_fields_set:
            _dict['base_product_name'] = None

        # set to None if base_product_short (nullable) is None
        # and model_fields_set contains the field
        if self.base_product_short is None and "base_product_short" in self.model_fields_set:
            _dict['base_product_short'] = None

        # set to None if base_product_version (nullable) is None
        # and model_fields_set contains the field
        if self.base_product_version is None and "base_product_version" in self.model_fields_set:
            _dict['base_product_version'] = None

        # set to None if instimage (nullable) is None
        # and model_fields_set contains the field
        if self.instimage is None and "instimage" in self.model_fields_set:
            _dict['instimage'] = None

        # set to None if mainimage (nullable) is None
        # and model_fields_set contains the field
        if self.mainimage is None and "mainimage" in self.model_fields_set:
            _dict['mainimage'] = None

        # set to None if discnum (nullable) is None
        # and model_fields_set contains the field
        if self.discnum is None and "discnum" in self.model_fields_set:
            _dict['discnum'] = None

        # set to None if totaldiscs (nullable) is None
        # and model_fields_set contains the field
        if self.totaldiscs is None and "totaldiscs" in self.model_fields_set:
            _dict['totaldiscs'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RpmDistributionTreeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from pulpcore.client.pulp_rpm.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_rpm.models.rpm_rpm_remote_response_hidden_fields_inner import RpmRpmRemoteResponseHiddenFieldsInner
from typing import Optional, Set
from typing_extensions import Self

class RpmUlnRemoteResponse(BaseModel):
    """
    A Serializer for UlnRemote.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the most recent update of the remote.")
    name: StrictStr = Field(description="A unique name for this remote.")
    url: StrictStr = Field(description="The ULN repo URL of the remote content source.\"This is \"uln://\" followed by the channel name. E.g.: \"uln://ol7_x86_64_oracle\"")
    ca_cert: Optional[StrictStr] = Field(default=None, description="A PEM encoded CA certificate used to validate the server certificate presented by the remote server.")
    client_cert: Optional[StrictStr] = Field(default=None, description="A PEM encoded client certificate used for authentication.")
    tls_validation: Optional[StrictBool] = Field(default=None, description="If True, TLS peer validation must be performed.")
    proxy_url: Optional[StrictStr] = Field(default=None, description="The proxy URL. Format: scheme://host:port")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = None
    download_concurrency: Optional[StrictInt] = Field(default=None, description="Total number of simultaneous connections. If not set then the default value will be used.")
    max_retries: Optional[StrictInt] = Field(default=None, description="Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.")
    policy: Optional[PolicyEnum] = Field(default=None, description="The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'immediate' is the default.  * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.")
    total_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    connect_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    sock_connect_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    sock_read_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    headers: Optional[List[Dict[str, Any]]] = Field(default=None, description="Headers for aiohttp.Clientsession")
    rate_limit: Optional[StrictInt] = Field(default=None, description="Limits requests per second for each concurrent downloader")
    hidden_fields: Optional[List[RpmRpmRemoteResponseHiddenFieldsInner]] = Field(default=None, description="List of hidden (write only) fields")
    uln_server_base_url: Optional[StrictStr] = Field(default=None, description="Base URL of the ULN server. If the uln_server_base_url is not provided pulp_rpm willuse the contents of the DEFAULT_ULN_SERVER_BASE_URL setting instead.")
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "pulp_created", "pulp_last_updated", "name", "url", "ca_cert", "client_cert", "tls_validation", "proxy_url", "pulp_labels", "download_concurrency", "max_retries", "policy", "total_timeout", "connect_timeout", "sock_connect_timeout", "sock_read_timeout", "headers", "rate_limit", "hidden_fields", "uln_server_base_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RpmUlnRemoteResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "pulp_created",
            "pulp_last_updated",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in hidden_fields (list)
        _items = []
        if self.hidden_fields:
            for _item_hidden_fields in self.hidden_fields:
                if _item_hidden_fields:
                    _items.append(_item_hidden_fields.to_dict())
            _dict['hidden_fields'] = _items
        # set to None if ca_cert (nullable) is None
        # and model_fields_set contains the field
        if self.ca_cert is None and "ca_cert" in self.model_fields_set:
            _dict['ca_cert'] = None

        # set to None if client_cert (nullable) is None
        # and model_fields_set contains the field
        if self.client_cert is None and "client_cert" in self.model_fields_set:
            _dict['client_cert'] = None

        # set to None if proxy_url (nullable) is None
        # and model_fields_set contains the field
        if self.proxy_url is None and "proxy_url" in self.model_fields_set:
            _dict['proxy_url'] = None

        # set to None if download_concurrency (nullable) is None
        # and model_fields_set contains the field
        if self.download_concurrency is None and "download_concurrency" in self.model_fields_set:
            _dict['download_concurrency'] = None

        # set to None if max_retries (nullable) is None
        # and model_fields_set contains the field
        if self.max_retries is None and "max_retries" in self.model_fields_set:
            _dict['max_retries'] = None

        # set to None if total_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.total_timeout is None and "total_timeout" in self.model_fields_set:
            _dict['total_timeout'] = None

        # set to None if connect_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.connect_timeout is None and "connect_timeout" in self.model_fields_set:
            _dict['connect_timeout'] = None

        # set to None if sock_connect_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.sock_connect_timeout is None and "sock_connect_timeout" in self.model_fields_set:
            _dict['sock_connect_timeout'] = None

        # set to None if sock_read_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.sock_read_timeout is None and "sock_read_timeout" in self.model_fields_set:
            _dict['sock_read_timeout'] = None

        # set to None if rate_limit (nullable) is None
        # and model_fields_set contains the field
        if self.rate_limit is None and "rate_limit" in self.model_fields_set:
            _dict['rate_limit'] = None

        # set to None if uln_server_base_url (nullable) is None
        # and model_fields_set contains the field
        if self.uln_server_base_url is None and "uln_server_base_url" in self.model_fields_set:
            _dict['uln_server_base_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RpmUlnRemoteResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class RpmModulemdObsolete(BaseModel):
    """
    ModulemdObsolete serializer.
    """ # noqa: E501
    repository: Optional[StrictStr] = Field(default=None, description="A URI of a repository the new content unit should be associated with.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = Field(default=None, description="A dictionary of arbitrary key/value pairs used to describe a specific Content instance.")
    modified: Annotated[str, Field(min_length=1, strict=True)] = Field(description="Obsolete modified time.")
    module_name: Annotated[str, Field(min_length=1, strict=True)] = Field(description="Modulemd name.")
    module_stream: Annotated[str, Field(min_length=1, strict=True)] = Field(description="Modulemd's stream.")
    message: Annotated[str, Field(min_length=1, strict=True)] = Field(description="Obsolete description.")
    override_previous: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(description="Reset previous obsoletes.")
    module_context: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(description="Modulemd's context.")
    eol_date: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(description="End of Life date.")
    obsoleted_by_module_name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(description="Obsolete by module name.")
    obsoleted_by_module_stream: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(description="Obsolete by module stream.")
    snippet: Annotated[str, Field(min_length=1, strict=True)] = Field(description="Module Obsolete snippet.")
    __properties: ClassVar[List[str]] = ["repository", "pulp_labels", "modified", "module_name", "module_stream", "message", "override_previous", "module_context", "eol_date", "obsoleted_by_module_name", "obsoleted_by_module_stream", "snippet"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RpmModulemdObsolete from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if override_previous (nullable) is None
        # and model_fields_set contains the field
        if self.override_previous is None and "override_previous" in self.model_fields_set:
            _dict['override_previous'] = None

        # set to None if module_context (nullable) is None
        # and model_fields_set contains the field
        if self.module_context is None and "module_context" in self.model_fields_set:
            _dict['module_context'] = None

        # set to None if eol_date (nullable) is None
        # and model_fields_set contains the field
        if self.eol_date is None and "eol_date" in self.model_fields_set:
            _dict['eol_date'] = None

        # set to None if obsoleted_by_module_name (nullable) is None
        # and model_fields_set contains the field
        if self.obsoleted_by_module_name is None and "obsoleted_by_module_name" in self.model_fields_set:
            _dict['obsoleted_by_module_name'] = None

        # set to None if obsoleted_by_module_stream (nullable) is None
        # and model_fields_set contains the field
        if self.obsoleted_by_module_stream is None and "obsoleted_by_module_stream" in self.model_fields_set:
            _dict['obsoleted_by_module_stream'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RpmModulemdObsolete from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.rpm_update_record_response import RpmUpdateRecordResponse

class TestRpmUpdateRecordResponse(unittest.TestCase):
    """RpmUpdateRecordResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RpmUpdateRecordResponse:
        """Test RpmUpdateRecordResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RpmUpdateRecordResponse`
        """
        model = RpmUpdateRecordResponse()
        if include_optional:
            return RpmUpdateRecordResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_labels = {
                    'key' : ''
                    },
                vuln_report = '',
                id = '',
                updated_date = '',
                description = '',
                issued_date = '',
                fromstr = '',
                status = '',
                title = '',
                summary = '',
                version = '',
                type = '',
                severity = '',
                solution = '',
                release = '',
                rights = '',
                pushcount = '',
                pkglist = [
                    pulpcore.client.pulp_rpm.models.rpm/update_collection_response.rpm.UpdateCollectionResponse(
                        name = '', 
                        shortname = '', 
                        module = null, 
                        packages = [
                            None
                            ], )
                    ],
                references = [
                    None
                    ],
                reboot_suggested = True
            )
        else:
            return RpmUpdateRecordResponse(
        )
        """

    def testRpmUpdateRecordResponse(self):
        """Test RpmUpdateRecordResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class RpmPackageGroupResponse(BaseModel):
    """
    PackageGroup serializer.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = Field(default=None, description="A dictionary of arbitrary key/value pairs used to describe a specific Content instance.")
    vuln_report: Optional[StrictStr] = None
    id: StrictStr = Field(description="PackageGroup id.")
    default: Optional[StrictBool] = Field(default=None, description="PackageGroup default.")
    user_visible: Optional[StrictBool] = Field(default=None, description="PackageGroup user visibility.")
    display_order: Optional[StrictInt] = Field(description="PackageGroup display order.")
    name: StrictStr = Field(description="PackageGroup name.")
    description: StrictStr = Field(description="PackageGroup description.")
    packages: Optional[Any] = Field(description="PackageGroup package list.")
    biarch_only: Optional[StrictBool] = Field(default=None, description="PackageGroup biarch only.")
    desc_by_lang: Optional[Any] = Field(description="PackageGroup description by language.")
    name_by_lang: Optional[Any] = Field(description="PackageGroup name by language.")
    digest: StrictStr = Field(description="PackageGroup digest.")
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "pulp_created", "pulp_last_updated", "pulp_labels", "vuln_report", "id", "default", "user_visible", "display_order", "name", "description", "packages", "biarch_only", "desc_by_lang", "name_by_lang", "digest"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RpmPackageGroupResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "pulp_created",
            "pulp_last_updated",
            "vuln_report",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of packages
        if self.packages:
            _dict['packages'] = self.packages.to_dict()
        # override the default output from pydantic by calling `to_dict()` of desc_by_lang
        if self.desc_by_lang:
            _dict['desc_by_lang'] = self.desc_by_lang.to_dict()
        # override the default output from pydantic by calling `to_dict()` of name_by_lang
        if self.name_by_lang:
            _dict['name_by_lang'] = self.name_by_lang.to_dict()
        # set to None if display_order (nullable) is None
        # and model_fields_set contains the field
        if self.display_order is None and "display_order" in self.model_fields_set:
            _dict['display_order'] = None

        # set to None if packages (nullable) is None
        # and model_fields_set contains the field
        if self.packages is None and "packages" in self.model_fields_set:
            _dict['packages'] = None

        # set to None if desc_by_lang (nullable) is None
        # and model_fields_set contains the field
        if self.desc_by_lang is None and "desc_by_lang" in self.model_fields_set:
            _dict['desc_by_lang'] = None

        # set to None if name_by_lang (nullable) is None
        # and model_fields_set contains the field
        if self.name_by_lang is None and "name_by_lang" in self.model_fields_set:
            _dict['name_by_lang'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RpmPackageGroupResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class RpmPackageResponse(BaseModel):
    """
    A Serializer for Package.  Add serializers for the new fields defined in Package and add those fields to the Meta class keeping fields from the parent class as well. Provide help_text.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.")
    md5: Optional[StrictStr] = Field(default=None, description="The MD5 checksum if available.")
    sha1: Optional[StrictStr] = Field(default=None, description="The SHA-1 checksum if available.")
    sha224: Optional[StrictStr] = Field(default=None, description="The SHA-224 checksum if available.")
    sha256: Optional[StrictStr] = Field(default=None, description="The SHA-256 checksum if available.")
    sha384: Optional[StrictStr] = Field(default=None, description="The SHA-384 checksum if available.")
    sha512: Optional[StrictStr] = Field(default=None, description="The SHA-512 checksum if available.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = Field(default=None, description="A dictionary of arbitrary key/value pairs used to describe a specific Content instance.")
    vuln_report: Optional[StrictStr] = None
    artifact: Optional[StrictStr] = Field(default=None, description="Artifact file representing the physical content")
    name: Optional[StrictStr] = Field(default=None, description="Name of the package")
    epoch: Optional[StrictStr] = Field(default=None, description="The package's epoch")
    version: Optional[StrictStr] = Field(default=None, description="The version of the package. For example, '2.8.0'")
    release: Optional[StrictStr] = Field(default=None, description="The release of a particular version of the package. e.g. '1.el7' or '3.f24'")
    arch: Optional[StrictStr] = Field(default=None, description="The target architecture for a package.For example, 'x86_64', 'i686', or 'noarch'")
    pkg_id: Optional[StrictStr] = Field(default=None, description="Checksum of the package file", alias="pkgId")
    checksum_type: Optional[StrictStr] = Field(default=None, description="Type of checksum, e.g. 'sha256', 'md5'")
    summary: Optional[StrictStr] = Field(default=None, description="Short description of the packaged software")
    description: Optional[StrictStr] = Field(default=None, description="In-depth description of the packaged software")
    url: Optional[StrictStr] = Field(default=None, description="URL with more information about the packaged software")
    changelogs: Optional[Any] = None
    files: Optional[Any] = None
    requires: Optional[Any] = None
    provides: Optional[Any] = None
    conflicts: Optional[Any] = None
    obsoletes: Optional[Any] = None
    suggests: Optional[Any] = None
    enhances: Optional[Any] = None
    recommends: Optional[Any] = None
    supplements: Optional[Any] = None
    location_base: Optional[StrictStr] = Field(default=None, description="DEPRECATED: Base location of this package. This field will be removed in a future release of pulp_rpm.")
    location_href: Optional[StrictStr] = Field(default=None, description="DEPRECATED: Relative location of package to the repodata. This field will be removed in a future release of pulp_rpm.")
    rpm_buildhost: Optional[StrictStr] = Field(default=None, description="Hostname of the system that built the package")
    rpm_group: Optional[StrictStr] = Field(default=None, description="RPM group (See: http://fedoraproject.org/wiki/RPMGroups)")
    rpm_license: Optional[StrictStr] = Field(default=None, description="License term applicable to the package software (GPLv2, etc.)")
    rpm_packager: Optional[StrictStr] = Field(default=None, description="Person or persons responsible for creating the package")
    rpm_sourcerpm: Optional[StrictStr] = Field(default=None, description="Name of the source package (srpm) the package was built from")
    rpm_vendor: Optional[StrictStr] = Field(default=None, description="Name of the organization that produced the package")
    rpm_header_start: Optional[StrictInt] = Field(default=None, description="First byte of the header")
    rpm_header_end: Optional[StrictInt] = Field(default=None, description="Last byte of the header")
    is_modular: Optional[StrictBool] = Field(default=None, description="Flag to identify if the package is modular")
    size_archive: Optional[StrictInt] = Field(default=None, description="Size, in bytes, of the archive portion of the original package file")
    size_installed: Optional[StrictInt] = Field(default=None, description="Total size, in bytes, of every file installed by this package")
    size_package: Optional[StrictInt] = Field(default=None, description="Size, in bytes, of the package")
    time_build: Optional[StrictInt] = Field(default=None, description="Time the package was built in seconds since the epoch")
    time_file: Optional[StrictInt] = Field(default=None, description="The 'file' time attribute in the primary XML - file mtime in seconds since the epoch.")
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "pulp_created", "pulp_last_updated", "md5", "sha1", "sha224", "sha256", "sha384", "sha512", "pulp_labels", "vuln_report", "artifact", "name", "epoch", "version", "release", "arch", "pkgId", "checksum_type", "summary", "description", "url", "changelogs", "files", "requires", "provides", "conflicts", "obsoletes", "suggests", "enhances", "recommends", "supplements", "location_base", "location_href", "rpm_buildhost", "rpm_group", "rpm_license", "rpm_packager", "rpm_sourcerpm", "rpm_vendor", "rpm_header_start", "rpm_header_end", "is_modular", "size_archive", "size_installed", "size_package", "time_build", "time_file"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RpmPackageResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "pulp_created",
            "pulp_last_updated",
            "md5",
            "sha1",
            "sha224",
            "sha256",
            "sha384",
            "sha512",
            "vuln_report",
            "name",
            "epoch",
            "version",
            "release",
            "arch",
            "pkg_id",
            "checksum_type",
            "summary",
            "description",
            "url",
            "location_base",
            "location_href",
            "rpm_buildhost",
            "rpm_group",
            "rpm_license",
            "rpm_packager",
            "rpm_sourcerpm",
            "rpm_vendor",
            "rpm_header_start",
            "rpm_header_end",
            "is_modular",
            "size_archive",
            "size_installed",
            "size_package",
            "time_build",
            "time_file",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if changelogs (nullable) is None
        # and model_fields_set contains the field
        if self.changelogs is None and "changelogs" in self.model_fields_set:
            _dict['changelogs'] = None

        # set to None if files (nullable) is None
        # and model_fields_set contains the field
        if self.files is None and "files" in self.model_fields_set:
            _dict['files'] = None

        # set to None if requires (nullable) is None
        # and model_fields_set contains the field
        if self.requires is None and "requires" in self.model_fields_set:
            _dict['requires'] = None

        # set to None if provides (nullable) is None
        # and model_fields_set contains the field
        if self.provides is None and "provides" in self.model_fields_set:
            _dict['provides'] = None

        # set to None if conflicts (nullable) is None
        # and model_fields_set contains the field
        if self.conflicts is None and "conflicts" in self.model_fields_set:
            _dict['conflicts'] = None

        # set to None if obsoletes (nullable) is None
        # and model_fields_set contains the field
        if self.obsoletes is None and "obsoletes" in self.model_fields_set:
            _dict['obsoletes'] = None

        # set to None if suggests (nullable) is None
        # and model_fields_set contains the field
        if self.suggests is None and "suggests" in self.model_fields_set:
            _dict['suggests'] = None

        # set to None if enhances (nullable) is None
        # and model_fields_set contains the field
        if self.enhances is None and "enhances" in self.model_fields_set:
            _dict['enhances'] = None

        # set to None if recommends (nullable) is None
        # and model_fields_set contains the field
        if self.recommends is None and "recommends" in self.model_fields_set:
            _dict['recommends'] = None

        # set to None if supplements (nullable) is None
        # and model_fields_set contains the field
        if self.supplements is None and "supplements" in self.model_fields_set:
            _dict['supplements'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RpmPackageResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.rpm_modulemd import RpmModulemd

class TestRpmModulemd(unittest.TestCase):
    """RpmModulemd unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RpmModulemd:
        """Test RpmModulemd
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RpmModulemd`
        """
        model = RpmModulemd()
        if include_optional:
            return RpmModulemd(
                repository = '',
                pulp_labels = {
                    'key' : ''
                    },
                name = '0',
                stream = '0',
                version = '0',
                static_context = True,
                context = '0',
                arch = '0',
                artifacts = None,
                dependencies = None,
                packages = [
                    ''
                    ],
                snippet = '0',
                profiles = None,
                description = '0'
            )
        else:
            return RpmModulemd(
                name = '0',
                stream = '0',
                version = '0',
                context = '0',
                arch = '0',
                artifacts = None,
                dependencies = None,
                snippet = '0',
                profiles = None,
                description = '0',
        )
        """

    def testRpmModulemd(self):
        """Test RpmModulemd"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.rpm_distribution_tree_response import RpmDistributionTreeResponse

class TestRpmDistributionTreeResponse(unittest.TestCase):
    """RpmDistributionTreeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RpmDistributionTreeResponse:
        """Test RpmDistributionTreeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RpmDistributionTreeResponse`
        """
        model = RpmDistributionTreeResponse()
        if include_optional:
            return RpmDistributionTreeResponse(
                pulp_href = '',
                prn = '',
                header_version = '',
                release_name = '',
                release_short = '',
                release_version = '',
                release_is_layered = True,
                base_product_name = '',
                base_product_short = '',
                base_product_version = '',
                arch = '',
                build_timestamp = 1.337,
                instimage = '',
                mainimage = '',
                discnum = 56,
                totaldiscs = 56,
                addons = [
                    pulpcore.client.pulp_rpm.models.addon_response.AddonResponse(
                        addon_id = '', 
                        uid = '', 
                        name = '', 
                        type = '', 
                        packages = '', )
                    ],
                checksums = [
                    pulpcore.client.pulp_rpm.models.checksum_response.ChecksumResponse(
                        path = '', 
                        checksum = '', )
                    ],
                images = [
                    pulpcore.client.pulp_rpm.models.image_response.ImageResponse(
                        name = '', 
                        path = '', 
                        platforms = '', 
                        artifact = pulpcore.client.pulp_rpm.models.artifact_response.ArtifactResponse(
                            pulp_href = '', 
                            prn = '', 
                            pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            file = '', 
                            size = 56, 
                            md5 = '', 
                            sha1 = '', 
                            sha224 = '', 
                            sha256 = '', 
                            sha384 = '', 
                            sha512 = '', ), )
                    ],
                variants = [
                    pulpcore.client.pulp_rpm.models.variant_response.VariantResponse(
                        variant_id = '', 
                        uid = '', 
                        name = '', 
                        type = '', 
                        packages = '', 
                        source_packages = '', 
                        source_repository = '', 
                        debug_packages = '', 
                        debug_repository = '', 
                        identity = '', )
                    ]
            )
        else:
            return RpmDistributionTreeResponse(
                header_version = '',
                release_name = '',
                release_short = '',
                release_version = '',
                release_is_layered = True,
                base_product_name = '',
                base_product_short = '',
                base_product_version = '',
                arch = '',
                build_timestamp = 1.337,
                instimage = '',
                mainimage = '',
                discnum = 56,
                totaldiscs = 56,
                addons = [
                    pulpcore.client.pulp_rpm.models.addon_response.AddonResponse(
                        addon_id = '', 
                        uid = '', 
                        name = '', 
                        type = '', 
                        packages = '', )
                    ],
                checksums = [
                    pulpcore.client.pulp_rpm.models.checksum_response.ChecksumResponse(
                        path = '', 
                        checksum = '', )
                    ],
                images = [
                    pulpcore.client.pulp_rpm.models.image_response.ImageResponse(
                        name = '', 
                        path = '', 
                        platforms = '', 
                        artifact = pulpcore.client.pulp_rpm.models.artifact_response.ArtifactResponse(
                            pulp_href = '', 
                            prn = '', 
                            pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            file = '', 
                            size = 56, 
                            md5 = '', 
                            sha1 = '', 
                            sha224 = '', 
                            sha256 = '', 
                            sha384 = '', 
                            sha512 = '', ), )
                    ],
                variants = [
                    pulpcore.client.pulp_rpm.models.variant_response.VariantResponse(
                        variant_id = '', 
                        uid = '', 
                        name = '', 
                        type = '', 
                        packages = '', 
                        source_packages = '', 
                        source_repository = '', 
                        debug_packages = '', 
                        debug_repository = '', 
                        identity = '', )
                    ],
        )
        """

    def testRpmDistributionTreeResponse(self):
        """Test RpmDistributionTreeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from pulpcore.client.pulp_rpm.models.compression_type_enum import CompressionTypeEnum
from pulpcore.client.pulp_rpm.models.layout_enum import LayoutEnum
from pulpcore.client.pulp_rpm.models.package_checksum_type_enum import PackageChecksumTypeEnum
from typing import Optional, Set
from typing_extensions import Self

class PatchedrpmRpmRepository(BaseModel):
    """
    Serializer for Rpm Repositories.
    """ # noqa: E501
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = None
    name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A unique name for this repository.")
    description: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="An optional description.")
    retain_repo_versions: Optional[StrictInt] = Field(default=None, description="Retain X versions of the repository. Default is null which retains all versions.")
    remote: Optional[StrictStr] = Field(default=None, description="An optional remote to use by default when syncing.")
    autopublish: Optional[StrictBool] = Field(default=False, description="Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.")
    metadata_signing_service: Optional[StrictStr] = Field(default=None, description="A reference to an associated signing service.")
    package_signing_service: Optional[StrictStr] = Field(default=None, description="A reference to an associated package signing service.")
    package_signing_fingerprint: Optional[Annotated[str, Field(strict=True, max_length=40)]] = Field(default='', description="The pubkey V4 fingerprint (160 bits) to be passed to the package signing service.The signing service will use that on signing operations related to this repository.")
    retain_package_versions: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, description="The number of versions of each package to keep in the repository; older versions will be purged. The default is '0', which will disable this feature and keep all versions of each package.")
    checksum_type: Optional[PackageChecksumTypeEnum] = Field(default=None, description="The preferred checksum type during repo publish.  * `unknown` - unknown * `md5` - md5 * `sha1` - sha1 * `sha224` - sha224 * `sha256` - sha256 * `sha384` - sha384 * `sha512` - sha512")
    repo_config: Optional[Any] = None
    compression_type: Optional[CompressionTypeEnum] = Field(default=None, description="The compression type to use for metadata files.  * `zstd` - zstd * `gz` - gz")
    layout: Optional[LayoutEnum] = Field(default=None, description="How to layout the packages within the published repository.  * `nested_alphabetically` - nested_alphabetically * `flat` - flat")
    __properties: ClassVar[List[str]] = ["pulp_labels", "name", "description", "retain_repo_versions", "remote", "autopublish", "metadata_signing_service", "package_signing_service", "package_signing_fingerprint", "retain_package_versions", "checksum_type", "repo_config", "compression_type", "layout"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedrpmRpmRepository from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if retain_repo_versions (nullable) is None
        # and model_fields_set contains the field
        if self.retain_repo_versions is None and "retain_repo_versions" in self.model_fields_set:
            _dict['retain_repo_versions'] = None

        # set to None if remote (nullable) is None
        # and model_fields_set contains the field
        if self.remote is None and "remote" in self.model_fields_set:
            _dict['remote'] = None

        # set to None if metadata_signing_service (nullable) is None
        # and model_fields_set contains the field
        if self.metadata_signing_service is None and "metadata_signing_service" in self.model_fields_set:
            _dict['metadata_signing_service'] = None

        # set to None if package_signing_service (nullable) is None
        # and model_fields_set contains the field
        if self.package_signing_service is None and "package_signing_service" in self.model_fields_set:
            _dict['package_signing_service'] = None

        # set to None if repo_config (nullable) is None
        # and model_fields_set contains the field
        if self.repo_config is None and "repo_config" in self.model_fields_set:
            _dict['repo_config'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedrpmRpmRepository from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from pulpcore.client.pulp_rpm.models.rpm_update_collection_response import RpmUpdateCollectionResponse
from typing import Optional, Set
from typing_extensions import Self

class RpmUpdateRecordResponse(BaseModel):
    """
    A Serializer for UpdateRecord.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = Field(default=None, description="A dictionary of arbitrary key/value pairs used to describe a specific Content instance.")
    vuln_report: Optional[StrictStr] = None
    id: Optional[StrictStr] = Field(default=None, description="Update id (short update name, e.g. RHEA-2013:1777)")
    updated_date: Optional[StrictStr] = Field(default=None, description="Date when the update was updated (e.g. '2013-12-02 00:00:00')")
    description: Optional[StrictStr] = Field(default=None, description="Update description")
    issued_date: Optional[StrictStr] = Field(default=None, description="Date when the update was issued (e.g. '2013-12-02 00:00:00')")
    fromstr: Optional[StrictStr] = Field(default=None, description="Source of the update (e.g. security@redhat.com)")
    status: Optional[StrictStr] = Field(default=None, description="Update status ('final', ...)")
    title: Optional[StrictStr] = Field(default=None, description="Update name")
    summary: Optional[StrictStr] = Field(default=None, description="Short summary")
    version: Optional[StrictStr] = Field(default=None, description="Update version (probably always an integer number)")
    type: Optional[StrictStr] = Field(default=None, description="Update type ('enhancement', 'bugfix', ...)")
    severity: Optional[StrictStr] = Field(default=None, description="Severity")
    solution: Optional[StrictStr] = Field(default=None, description="Solution")
    release: Optional[StrictStr] = Field(default=None, description="Update release")
    rights: Optional[StrictStr] = Field(default=None, description="Copyrights")
    pushcount: Optional[StrictStr] = Field(default=None, description="Push count")
    pkglist: Optional[List[RpmUpdateCollectionResponse]] = Field(default=None, description="List of packages")
    references: Optional[List[Dict[str, Any]]] = Field(default=None, description="List of references")
    reboot_suggested: Optional[StrictBool] = Field(default=None, description="Reboot suggested")
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "pulp_created", "pulp_last_updated", "pulp_labels", "vuln_report", "id", "updated_date", "description", "issued_date", "fromstr", "status", "title", "summary", "version", "type", "severity", "solution", "release", "rights", "pushcount", "pkglist", "references", "reboot_suggested"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RpmUpdateRecordResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "pulp_created",
            "pulp_last_updated",
            "vuln_report",
            "id",
            "updated_date",
            "description",
            "issued_date",
            "fromstr",
            "status",
            "title",
            "summary",
            "version",
            "type",
            "severity",
            "solution",
            "release",
            "rights",
            "pushcount",
            "reboot_suggested",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in pkglist (list)
        _items = []
        if self.pkglist:
            for _item_pkglist in self.pkglist:
                if _item_pkglist:
                    _items.append(_item_pkglist.to_dict())
            _dict['pkglist'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RpmUpdateRecordResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(obj)
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.rpm_rpm_repository_response import RpmRpmRepositoryResponse

class TestRpmRpmRepositoryResponse(unittest.TestCase):
    """RpmRpmRepositoryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RpmRpmRepositoryResponse:
        """Test RpmRpmRepositoryResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RpmRpmRepositoryResponse`
        """
        model = RpmRpmRepositoryResponse()
        if include_optional:
            return RpmRpmRepositoryResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                versions_href = '',
                pulp_labels = {
                    'key' : ''
                    },
                latest_version_href = '',
                name = '',
                description = '',
                retain_repo_versions = 56,
                remote = '',
                autopublish = True,
                metadata_signing_service = '',
                package_signing_service = '',
                package_signing_fingerprint = '',
                retain_package_versions = 0,
                checksum_type = 'unknown',
                metadata_checksum_type = 'unknown',
                package_checksum_type = 'unknown',
                gpgcheck = 0,
                repo_gpgcheck = 0,
                sqlite_metadata = True,
                repo_config = None,
                compression_type = 'zstd',
                layout = 'nested_alphabetically'
            )
        else:
            return RpmRpmRepositoryResponse(
                name = '',
        )
        """

    def testRpmRpmRepositoryResponse(self):
        """Test RpmRpmRepositoryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_rpm.models.policy_enum import PolicyEnum

class TestPolicyEnum(unittest.TestCase):
    """PolicyEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPolicyEnum(self):
        """Test PolicyEnum"""
        # inst = PolicyEnum()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PackageChecksumTypeEnum(str, Enum):
    """
    * `unknown` - unknown * `md5` - md5 * `sha1` - sha1 * `sha224` - sha224 * `sha256` - sha256 * `sha384` - sha384 * `sha512` - sha512
    """

    """
    allowed enum values
    """
    UNKNOWN = 'unknown'
    MD5 = 'md5'
    SHA1 = 'sha1'
    SHA224 = 'sha224'
    SHA256 = 'sha256'
    SHA384 = 'sha384'
    SHA512 = 'sha512'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PackageChecksumTypeEnum from a JSON string"""
        return cls(json.loads(json_str))


